| Title: | Irucka Embry's Miscellaneous USGS Data Collection |
|---|---|
| Description: | A collection of Irucka Embry's miscellaneous USGS data sets (USGS Parameter codes with fixed values, USGS global time zone codes, and US Air Force Global Engineering Weather Data). Irucka created these data sets while a Cherokee Nation Technology Solutions (CNTS) United States Geological Survey (USGS) Contractor and/or USGS employee. |
| Authors: | Irucka Embry [aut, cre] |
| Maintainer: | Irucka Embry <[email protected]> |
| License: | CC0 |
| Version: | 1.0.4 |
| Built: | 2026-05-17 06:30:16 UTC |
| Source: | https://gitlab.com/iembry/ie2miscdata |
A table containing the USGS Weather parameter codes.
pmcode_00041pmcode_00041
A data frame with 54 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Tide stage, code parameter codes.
pmcode_00067pmcode_00067
A data frame with 315 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Sample treatment parameter codes.
pmcode_00115pmcode_00115
A data frame with 4 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Oil-Grease (Severity) parameter codes.
pmcode_01300pmcode_01300
A data frame with 5 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Detergent Suds (Severity) parameter codes.
pmcode_01305pmcode_01305
A data frame with 5 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Gas Bubbles (Severity) parameter codes.
pmcode_01310pmcode_01310
A data frame with 5 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Sludge: Floating (Severity) parameter codes.
pmcode_01315pmcode_01315
A data frame with 5 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Garbage, Floating (Severity) parameter codes.
pmcode_01320pmcode_01320
A data frame with 5 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Algae, Floating Mats (Severity) parameter codes.
pmcode_01325pmcode_01325
A data frame with 5 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Odor, Atmospheric (Severity) parameter codes.
pmcode_01330pmcode_01330
A data frame with 5 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Sewage Solids, Fresh, Floating (Severity) parameter codes.
pmcode_01335pmcode_01335
A data frame with 5 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Fish, Dead (Severity) parameter codes.
pmcode_01340pmcode_01340
A data frame with 5 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Debris, Floating (Severity) parameter codes.
pmcode_01345pmcode_01345
A data frame with 5 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Turbidity (Severity) parameter codes.
pmcode_01350pmcode_01350
A data frame with 5 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Streamflow (Severity) parameter codes.
pmcode_01351pmcode_01351
A data frame with 5 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Ice Cover, Floating Or Solid (Severity) parameter codes.
pmcode_01355pmcode_01355
A data frame with 5 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Tether Line Used For Collecting Sample (Yes=1) Codes parameter codes.
pmcode_04117pmcode_04117
A data frame with 2 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Streptocci, Fecal, Tube Configuration parameter codes.
pmcode_31678pmcode_31678
A data frame with 8 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Degree Of Decomposition, Soil, Code parameter codes.
pmcode_49986pmcode_49986
A data frame with 3 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Filter Type, Code parameter codes.
pmcode_50276pmcode_50276
A data frame with 14 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Water Samples, Code parameter codes.
pmcode_50280pmcode_50280
A data frame with 28 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Sample Matrix, Code parameter codes.
pmcode_62955pmcode_62955
A data frame with 3 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Water Use, Primary (Codes) parameter codes.
pmcode_71995pmcode_71995
A data frame with 131 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Water Use, Secondary (Codes) parameter codes.
pmcode_71996pmcode_71996
A data frame with 131 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Water Use, Tertiary (Codes) parameter codes.
pmcode_71997pmcode_71997
A data frame with 131 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Water Use, Quaternary (Codes) parameter codes.
pmcode_71998pmcode_71998
A data frame with 131 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Sample Purpose (Codes) parameter codes.
pmcode_71999pmcode_71999
A data frame with 28 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Sample Source (Codes) parameter codes.
pmcode_72005pmcode_72005
A data frame with 101 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Sampling Condition (Codes) parameter codes.
pmcode_72006pmcode_72006
A data frame with 46 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Sample Preservation Method, (Codes) parameter codes.
pmcode_74200pmcode_74200
A data frame with 119 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Atmospheric Deposition Type Bulk, (Codes) parameter codes.
pmcode_82305pmcode_82305
A data frame with 5 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Contamination Source, Possible (Codes) parameter codes.
pmcode_82309pmcode_82309
A data frame with 22 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Sampling Method (Codes) parameter codes.
pmcode_82398pmcode_82398
A data frame with 63 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Atmospheric Deposition Type Wet, (Codes) parameter codes.
pmcode_82923pmcode_82923
A data frame with 7 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Topography, Physiographic Setting (Codes) parameter codes.
pmcode_84060pmcode_84060
A data frame with 18 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Well Purging Condition (Codes) parameter codes.
pmcode_84143pmcode_84143
A data frame with 12 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Well Selection Criteria (Codes) parameter codes.
pmcode_84144pmcode_84144
A data frame with 2 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Project Component (Codes) parameter codes.
pmcode_84145pmcode_84145
A data frame with 7 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Land Use, Predominant, Within 200 Feet Of Well, (Codes) parameter codes.
pmcode_84146pmcode_84146
A data frame with 15 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Land Use, Predominant, Within 0.25 Mile Of Well (Codes) parameter codes.
pmcode_84147pmcode_84147
A data frame with 15 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Land Use, Predominant Fraction, Within 0.25 Mile Of Well (Codes) parameter codes.
pmcode_84148pmcode_84148
A data frame with 4 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Land-Use Changes Within Last 10 Years, Within 0.25 Mile Of Well (Codes) parameter codes.
pmcode_84149pmcode_84149
A data frame with 4 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Sampler Type, (Codes) parameter codes.
pmcode_84164pmcode_84164
A data frame with 121 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Sample Splitter Type, Field Code parameter codes.
pmcode_84171pmcode_84171
A data frame with 12 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Air Sampler Filter Type, Code parameter codes.
pmcode_84172pmcode_84172
A data frame with 4 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Air Sample Trap Sorbent Type, Code parameter codes.
pmcode_84173pmcode_84173
A data frame with 6 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Latitude/Longitude Horizontal Datum parameter codes.
pmcode_91112pmcode_91112
A data frame with 7 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Latitude/Longitude Measurement Method parameter codes.
pmcode_91113pmcode_91113
A data frame with 9 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Latitude/Longitude Coordinate Accuracy parameter codes.
pmcode_91114pmcode_91114
A data frame with 6 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Blank, Type Of Solution, Fixed Value Code parameter codes.
pmcode_99100pmcode_99100
A data frame with 13 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Blank, Source Of Solution, Fixed Value Code parameter codes.
pmcode_99101pmcode_99101
A data frame with 25 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Blank, Type Of Sample, Fixed Value Code parameter codes.
pmcode_99102pmcode_99102
A data frame with 13 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Reference Material, Source, Fixed Value Code parameter codes.
pmcode_99103pmcode_99103
A data frame with 12 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Replicate, Type, Fixed Value Code parameter codes.
pmcode_99105pmcode_99105
A data frame with 6 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Spike, Type, Fixed Value Code parameter codes.
pmcode_99106pmcode_99106
A data frame with 5 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Spike, Source, Fixed Value Code parameter codes.
pmcode_99107pmcode_99107
A data frame with 14 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Quality Assurance Data Type Associated With Sample, Code parameter codes.
pmcode_99111pmcode_99111
A data frame with 9 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Sulfide, Water, Filtered, Field, milligrams Per Liter parameter codes.
pmcode_99112pmcode_99112
A data frame with 10 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Coliphage, somatic, E. coli C-host, 2-stepenrichment presence/absence per 1 liter parameter codes.
pmcode_99329pmcode_99329
A data frame with 2 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS ColipgeF-spec, famp, 2-step,pres(1) abs(2)/ 1 L parameter codes.
pmcode_99335pmcode_99335
A data frame with 2 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Total coliform, ColilrtPA, wtrprs/abs /1L parameter codes.
pmcode_99595pmcode_99595
A data frame with 2 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS E. coliColilrt PA, water prs/abs /1 L parameter codes.
pmcode_99596pmcode_99596
A data frame with 2 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Entero- virus, RT pcrpres(1) abs(2) / 50 L parameter codes.
pmcode_99766pmcode_99766
A data frame with 2 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Reo- virus, RT pcrpres(1) abs(2) / 50 L parameter codes.
pmcode_99767pmcode_99767
A data frame with 2 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Rota virus, RT pcrpres(1) abs(2) / 50 L parameter codes.
pmcode_99768pmcode_99768
A data frame with 2 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Hepatitis-A virus, RT pcrpres(1) abs(2) / 50 L parameter codes.
pmcode_99769pmcode_99769
A data frame with 2 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Norwalk virus, RT pcrpres(1) abs(2) / 50 L parameter codes.
pmcode_99770pmcode_99770
A data frame with 2 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the USGS Calici- virus, RT pcrpres(1) abs(2) / 50 L parameter codes.
pmcode_99771pmcode_99771
A data frame with 2 rows and 3 variables:
USGS Parameter Code
Fixed Value
Fixed Text
This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See https://help.waterdata.usgs.gov/codes-and-parameters/.
A table containing the worldwide timezones and UTC offsets.
tz_codestz_codes
A data.table data frame with 54 rows and 7 variables:
Timezone Code
Timezone Name
Timezone Location
Timezone UTC Offset
Timezone Daylight Savings Code
Timezone Daylight Savings Name
Timezone Daylight Savings UTC Offset
This data is from National Water Information System: Help System Time Zone Codes. See https://help.waterdata.usgs.gov/code/tz_query?fmt=html.
"The data in this table were compiled by the Air Force Combat Climatology Center (AFCCC) at the request of the Air Force Civil Engineer Support Agency (HQ AFCESA). Sites were identified by AFCESA, US Army Corps of Engineers (USACE), and the Naval Facilities Engineering Command (NAVFACENGCOM). Final site selection was based upon availability of climatological data. Most sites are located at military installations supporting airfield operations or at local airports/airfields."
weather_resultsweather_results
A data.table data frame with 805 rows and 7 variables:
Name of location
"World Meteorological Organization (WMO) number is a unique number assigned to every location in the world that takes and transmits regular weather observations."
Location latitude, decimal degrees
Location longitude, decimal degrees
Location elevation, feet above mean sea level
Location wet-bulb temperature (degrees F) design value for a 1.0 percent occurrence (based on the whole year)
Location "mean coincident dry-bulb temperature" (degrees F) for a 1.0 percent occurrence (based on the whole year)
This data is from the ENGINEERING WEATHER DATA PRODUCTS (EWD) CD-ROM, version 1.0, 23 December 1999. CD-ROM provided by the National Climatic Data Center Climate Services Division. See https://www.ncei.noaa.gov/nespls/olstore.prodspecific?prodnum=5005.